@@ -318,7 +318,7 @@ class ApplicationActions:
             if App().player.current_track.id is not None and\
                     App().player.current_track.id > 0:
                 artist_ids = App().player.current_track.album.artist_ids
-                App().window.container.show_artist_view(artist_ids)
+                App().window.container.show_artists_albums(artist_ids)
         elif string == "loved":
             track = App().player.current_track
             if track.id is not None and track.id >= 0:
