@@ -56,14 +56,14 @@ class RadioPopover(Popover):
 
         track = Track()
         if radio_id is not None:
-            name = radios.get_name(radio_id)
+            name = self.__radios.get_name(radio_id)
             track.set_radio_id(radio_id)
             rating = RatingWidget(track)
             rating.show()
             builder.get_object("widget").attach(rating, 0, 2, 2, 1)
             builder.get_object("delete_button").show()
             self.__name_entry.set_text(name)
-            uri = radios.get_uri(radio_id)
+            uri = self.__radios.get_uri(radio_id)
             if uri:
                 self.__uri_entry.set_text(uri)
 
