@@ -52,6 +52,7 @@ class View(BaseView, Gtk.Grid):
         BaseView.__init__(self)
         Gtk.Grid.__init__(self)
         self._view_type = view_type
+        self.__adaptive_signal_id = None
         self.__overlayed = None
         self.__scanner_signal_id = App().scanner.connect(
             "album-updated", self._on_album_updated)
@@ -94,6 +95,10 @@ class View(BaseView, Gtk.Grid):
         self.connect("destroy", self.__on_destroy)
         self.connect("map", self._on_map)
         self.connect("unmap", self._on_unmap)
+        if not self._view_type & ViewType.NOT_ADAPTIVE:
+            self.__adaptive_signal_id = App().window.connect(
+                                                    "adaptive-changed",
+                                                    self._on_adaptive_changed)
         if not view_type & (ViewType.POPOVER | ViewType.SEARCH):
             self.get_style_context().add_class("view")
 
@@ -199,6 +204,12 @@ class View(BaseView, Gtk.Grid):
             return child.set_filtered(False)
         return child.set_filtered(True)
 
+    def _on_adaptive_changed(self, window, status):
+        """
+            Handle adaptive mode for views
+        """
+        pass
+
     def _on_search_changed(self, entry):
         """
             Update filter
@@ -273,6 +284,9 @@ class View(BaseView, Gtk.Grid):
             Clean up widget
             @param widget as Gtk.Widget
         """
+        if self.__adaptive_signal_id is not None:
+            App().window.disconnect(self.__adaptive_signal_id)
+            self.__adaptive_signal_id = None
         if self.__scanner_signal_id is not None:
             App().scanner.disconnect(self.__scanner_signal_id)
             self.__scanner_signal_id = None
@@ -291,20 +305,21 @@ class LazyLoadingView(View):
             @param view_type as ViewType
         """
         View.__init__(self, view_type)
-        self._lazy_queue = []  # Widgets not initialized
+        self._lazy_queue = []
         self.__priority_queue = []
-        self.__backup_queue = []
+        self.__lazy_loading_id = None
         self.__scroll_timeout_id = None
         self._scrolled.get_vadjustment().connect("value-changed",
                                                  self._on_value_changed)
         self.__start_time = time()
 
-    def stop(self):
+    def stop(self, clear=False):
         """
             Stop loading
+            @param clear as bool
         """
-        if self._lazy_queue or self.__priority_queue:
-            self.__backup_queue = self._lazy_queue + self.__priority_queue
+        self.__lazy_loading_id = None
+        if clear:
             self._lazy_queue = []
             self.__priority_queue = []
         View.stop(self)
@@ -313,18 +328,9 @@ class LazyLoadingView(View):
         """
             Load the view in a lazy way
         """
-        widget = None
-        if self.__priority_queue:
-            widget = self.__priority_queue.pop(0)
-            self._lazy_queue.remove(widget)
-        elif self._lazy_queue:
-            widget = self._lazy_queue.pop(0)
-        if widget is not None:
-            widget.connect("populated", self._on_populated)
-            widget.populate()
-        else:
-            Logger.debug("LazyLoadingView::lazy_loading(): %s",
-                         time() - self.__start_time)
+        # He we keep id just to check we are in current load
+        if self.__lazy_loading_id is None:
+            self.__lazy_loading_id = GLib.idle_add(self.__lazy_loading)
 
 #######################
 # PROTECTED           #
@@ -335,9 +341,8 @@ class LazyLoadingView(View):
             @param widget as Gtk.Widget
         """
         View._on_map(self, widget)
-        if self.__backup_queue:
-            self._lazy_queue = self.__backup_queue
-            GLib.idle_add(self.lazy_loading)
+        if self._lazy_queue:
+            self.lazy_loading()
 
     def _on_value_changed(self, adj):
         """
@@ -350,21 +355,46 @@ class LazyLoadingView(View):
             GLib.source_remove(self.__scroll_timeout_id)
         self.__scroll_timeout_id = GLib.timeout_add(200, self.__lazy_or_not)
 
-    def _on_populated(self, widget):
+    def _on_populated(self, widget, lazy_loading_id):
         """
             Add another album/disc
             @param widget as AlbumWidget/TracksView
+            @parma lazy_loading_id as int
         """
-        if self._lazy_queue is None:
+        if lazy_loading_id != self.__lazy_loading_id:
             return
         if not widget.is_populated:
             widget.populate()
         else:
-            GLib.idle_add(self.lazy_loading)
+            # Looks like there is an issue with signal handling in old
+            # pygobject => https://gitlab.gnome.org/World/lollypop/issues/1884
+            # Make sense, I removed GLib.idle_add() for 1.1.4 because I
+            # couldn't understand it...
+            GLib.idle_add(self.__lazy_loading)
 
 #######################
 # PRIVATE             #
 #######################
+    def __lazy_loading(self):
+        """
+            Load the view in a lazy way
+        """
+        widget = None
+        if self.__priority_queue:
+            widget = self.__priority_queue.pop(0)
+            self._lazy_queue.remove(widget)
+        elif self._lazy_queue:
+            widget = self._lazy_queue.pop(0)
+        if widget is not None:
+            widget.connect("populated",
+                           self._on_populated,
+                           self.__lazy_loading_id)
+            widget.populate()
+        else:
+            self.__lazy_loading_id = None
+            Logger.debug("LazyLoadingView::lazy_loading(): %s",
+                         time() - self.__start_time)
+
     def __is_visible(self, widget):
         """
             Is widget visible in scrolled
@@ -383,11 +413,10 @@ class LazyLoadingView(View):
         """
             Add visible widgets to lazy queue
         """
+        if self.__lazy_loading_id is None:
+            return
         self.__scroll_timeout_id = None
         self.__priority_queue = []
-        if self._lazy_queue is None:
-            return
         for child in self._lazy_queue:
             if self.__is_visible(child):
                 self.__priority_queue.append(child)
-        GLib.idle_add(self.lazy_loading)
