@@ -14,6 +14,7 @@ from gi.repository import Gtk, GLib
 
 from lollypop.view import LazyLoadingView
 from lollypop.define import ViewType
+from lollypop.utils import get_font_height
 
 
 class FlowBoxView(LazyLoadingView):
@@ -27,8 +28,9 @@ class FlowBoxView(LazyLoadingView):
             @param view_type as ViewType
         """
         LazyLoadingView.__init__(self, view_type | ViewType.FILTERED)
+        self.__adaptive_signal_id = None
         self._widget_class = None
-        self._items = []
+        self.__font_height = get_font_height()
         self._box = Gtk.FlowBox()
         self._box.set_filter_func(self._filter_func)
         self._box.set_selection_mode(Gtk.SelectionMode.NONE)
@@ -50,11 +52,18 @@ class FlowBoxView(LazyLoadingView):
             @param items
         """
         if items and self._box.get_visible():
-            self._items = items
-            GLib.idle_add(self._add_items, self._items)
+            GLib.idle_add(self._add_items, items)
         else:
             LazyLoadingView.populate(self)
 
+    @property
+    def font_height(self):
+        """
+            Get font height
+            @return int
+        """
+        return self.__font_height
+
     @property
     def children(self):
         """
@@ -84,14 +93,14 @@ class FlowBoxView(LazyLoadingView):
             return
         if items:
             widget = self._widget_class(
-                items.pop(0), *args)
+                items.pop(0), *args, self.__font_height)
             self._box.insert(widget, -1)
             widget.show()
             self._lazy_queue.append(widget)
             GLib.idle_add(self._add_items, items)
             return widget
         else:
-            GLib.idle_add(self.lazy_loading)
+            self.lazy_loading()
             if self._view_type & ViewType.SCROLLED:
                 if self._viewport.get_child() is None:
                     self._viewport.add(self._box)
@@ -110,6 +119,30 @@ class FlowBoxView(LazyLoadingView):
     def _on_item_activated(self, flowbox, widget):
         pass
 
+    def _on_adaptive_changed(self, window, status):
+        """
+            Update artwork
+            @param window as Window
+            @param status as bool
+        """
+        def update_artwork(children):
+            if children:
+                child = children.pop(0)
+                child.set_artwork()
+                GLib.idle_add(update_artwork, children)
+
+        self.stop(True)
+        if status:
+            view_type = self._view_type | ViewType.MEDIUM
+        else:
+            view_type = self._view_type & ~ViewType.MEDIUM
+        children = self._box.get_children()
+        for child in children:
+            child.set_view_type(view_type)
+            child.disable_artwork()
+            self._lazy_queue.append(child)
+        self.lazy_loading()
+
 #######################
 # PRIVATE             #
 #######################
