@@ -179,7 +179,7 @@ class InformationView(BaseView, Gtk.Bin):
             popover.popdown()
         if App().player.current_track.id is None:
             return
-        GLib.idle_add(App().window.container.show_artist_view,
+        GLib.idle_add(App().window.container.show_artists_albums,
                       App().player.current_track.album.artist_ids)
 
     def __on_label_button_release_event(self, button, event):
