@@ -20,13 +20,15 @@ class AlbumsDecadeWidget(RoundedAlbumsWidget, OverlayDecadeHelper):
         Decade widget showing cover for 4 albums
     """
 
-    def __init__(self, item_ids, view_type):
+    def __init__(self, item_ids, view_type, font_height):
         """
             Init widget
             @param decade as [int]
             @param view_type as ViewType
+            @param font_height as int
         """
         OverlayDecadeHelper.__init__(self)
+        self.__font_height = font_height
         decade_str = "%s - %s" % (item_ids[0], item_ids[-1])
         RoundedAlbumsWidget.__init__(self, item_ids, decade_str,
                                      decade_str, view_type)
@@ -36,29 +38,42 @@ class AlbumsDecadeWidget(RoundedAlbumsWidget, OverlayDecadeHelper):
         """
             Populate widget content
         """
-        self._lock_overlay = False
-        self.__set_album_ids()
-        RoundedAlbumsWidget.populate(self)
-        self._widget.connect("enter-notify-event", self._on_enter_notify)
-        self._widget.connect("leave-notify-event", self._on_leave_notify)
+        if self._artwork is None:
+            self._lock_overlay = False
+            RoundedAlbumsWidget.populate(self)
+            self._widget.connect("enter-notify-event", self._on_enter_notify)
+            self._widget.connect("leave-notify-event", self._on_leave_notify)
+        else:
+            self.set_artwork()
+
+    def set_view_type(self, view_type):
+        """
+            Update view type
+            @param view_type as ViewType
+        """
+        RoundedAlbumsWidget.set_view_type(self, view_type)
+        self.set_size_request(self._art_size,
+                              self._art_size + self.__font_height)
 
 #######################
 # PROTECTED           #
 #######################
+    def _get_album_ids(self):
+        """
+            Get album ids
+            @return [int]
+        """
+        album_ids = []
+        for year in self._data:
+            album_ids += App().albums.get_albums_for_year(year,
+                                                          self._ALBUMS_COUNT)
+            l = len(album_ids)
+            if l < self._ALBUMS_COUNT:
+                album_ids += App().albums.get_compilations_for_year(
+                                                       year,
+                                                       self._ALBUMS_COUNT)
+        return album_ids
 
 #######################
 # PRIVATE             #
 #######################
-    def __set_album_ids(self):
-        """
-            Set album ids
-        """
-        for year in self._data:
-            self._album_ids += App().albums.get_albums_for_year(
-                                                          year,
-                                                          self._ALBUMS_COUNT)
-            l = len(self._album_ids)
-            if l < self._ALBUMS_COUNT:
-                self._album_ids += App().albums.get_compilations_for_year(
-                                                       year,
-                                                       self._ALBUMS_COUNT)
